"""
Acumbamail SDK for Python.

This package provides a Python client for the Acumbamail API.
"""

from .client import *  # noqa
from .aclient import *  # noqa
from .exceptions import *  # noqa
from .models import *  # noqa

__version__ = "1.0.0"
